Learn R Programming

cthist (version 2.1.12)

clinicaltrials_gov_dates: Download a table of dates on which a ClinicalTrials.gov registry entry was updated

Description

Download a table of dates on which a ClinicalTrials.gov registry entry was updated

Usage

clinicaltrials_gov_dates(nctids, status_change_only = FALSE, quiet = TRUE)

Value

A table with three columns: the version number (starting from 0), the ISO-8601 formatted date on which there were clinical trial history version updates, and the trial's overall status on that date.

Arguments

nctids

A list of well-formed NCT numbers, e.g. c("NCT00942747", "NCT03281616"). (A capitalized "NCT" followed by eight numerals with no spaces or hyphens.)

status_change_only

If TRUE, returns only the dates marked with a Recruitment Status change, default FALSE.

quiet

A boolean TRUE or FALSE. If TRUE, no messages will be printed during download. TRUE by default, messages printed for every registry entry downloaded showing progress.

Examples

Run this code

# \donttest{
versions <- clinicaltrials_gov_dates("NCT00942747")
# }

Run the code above in your browser using DataLab